==> react-native-payment_library_test-1.0.0.tgz: package/src/Components/HomeComponent/HomeComponent.js <==
import React, { PureComponent } from 'react';  
import { AppRegistry, FlatList,  
    StyleSheet, Text, View } from 'react-native';  
  
class HomeComponent extends PureComponent {  
  
  constructor(props) {
    super(props);
  }
    renderSeparator = () => {  
        return (  
            <View  
                style={{  
                    height: 1,  
                    width: "100%",  
                    backgroundColor: "#000",  
                }}  
            />  
        );  
    };  
    //handling onPress action  
    getListViewItem = (item) => {  
      if(item.key === 'RazorPay') {
        this.props.navigation.navigate('RazorPayComponent');
      }else {
        this.props.navigation.navigate('PaypalComponent');
      }
    }  
  
    render() {  
        return (  
             <View style={styles.container}>  
                <FlatList  
                    data={[  
                       {key: 'RazorPay'},{key: 'PaypalComponent'}  
                    ]}  
                    renderItem={({item}) =>  
                        <Text style={styles.item}  
                              onPress={this.getListViewItem.bind(this, item)}>{item.key}</Text>}  
                    ItemSeparatorComponent={this.renderSeparator}  
                />  
            </View>  
        );  
    }  
}  
  
const styles = StyleSheet.create({  
    container: {  
        flex: 1,  
    },  
    item: {  
        padding: 10,  
        fontSize: 18,  
        height: 44,  
    },  
})  

export default HomeComponent;

==> react-native-payment_library_test3-1.0.0.tgz: package/src/Components/HomeComponent/HomeComponent.js <==
import React, { PureComponent } from 'react';  
import { AppRegistry, FlatList,  
    StyleSheet, Text, View } from 'react-native';  
  
class HomeComponent extends PureComponent {  
  
  constructor(props) {
    super(props);
    this.state = {
        amount: ''
    }
  }

  componentWillMount() {
    const { navigation } = this.props;  
    const amt = navigation.getParam('amount', '0');  
    console.log('Amount:' + amt);
    this.setState({ amount: amt });
  }

    renderSeparator = () => {  
        return (  
            <View  
                style={{  
                    height: 1,  
                    width: "100%",  
                    backgroundColor: "#000",  
                }}  
            />  
        );  
    };  
    //handling onPress action  
    getListViewItem = (item) => {  
      if(item.key === 'RazorPay') {
        this.props.navigation.navigate('RazorPayComponent', {  
            amount: this.state.amount,  
        });
      }else {
        this.props.navigation.navigate('PaypalComponent', {  
            amount: this.state.amount,  
        });  
      }
    }  
  
    render() {  
        return (  
             <View style={styles.container}>  
                <FlatList  
                    data={[  
                       {key: 'RazorPay'},{key: 'Paypal'}  
                    ]}  
                    renderItem={({item}) =>  
                        <Text style={styles.item}  
                              onPress={this.getListViewItem.bind(this, item)}>{item.key}</Text>}  
                    ItemSeparatorComponent={this.renderSeparator}  
                />  
            </View>  
        );  
    }  
}  
  
const styles = StyleSheet.create({  
    container: {  
        flex: 1,  
    },  
    item: {  
        padding: 10,  
        fontSize: 18,  
        height: 44,  
    },  
})  

export default HomeComponent;
